@@ -11,11 +11,20 @@ mod pprint;
 enum Command {
     /// Fetches the specified URL and pretty-prints the certificate.
     #[clap(name = "print")]
-    PPrint { url: String },
+    PPrint {
+        url: String,
+
+        /// Specifies one or more encodings to accept.
+        #[clap(long, multiple(true), number_of_values(1))]
+        accept_encoding: Option<Vec<String>>,
+    },
 }
 
 fn main() -> Result<()> {
     match Command::parse() {
-        Command::PPrint { url } => pprint::pprint(url),
+        Command::PPrint {
+            url,
+            accept_encoding,
+        } => pprint::pprint(url, accept_encoding),
     }
 }
